@@ -35,12 +35,16 @@ type Fs struct {
 	// Destination is Hugo's destination file system.
 	Destination afero.Fs
 
+	// Destination used for `renderStaticToDisk`
+	DestinationStatic afero.Fs
+
 	// Os is an OS file system.
 	// NOTE: Field is currently unused.
 	Os afero.Fs
 
 	// WorkingDir is a read-only file system
 	// restricted to the project working dir.
+	// TODO(bep) get rid of this (se BaseFs)
 	WorkingDir *afero.BasePathFs
 }
 
@@ -68,10 +72,11 @@ func NewFrom(fs afero.Fs, cfg config.Provider) *Fs {
 
 func newFs(base afero.Fs, cfg config.Provider) *Fs {
 	return &Fs{
-		Source:      base,
-		Destination: base,
-		Os:          &afero.OsFs{},
-		WorkingDir:  getWorkingDirFs(base, cfg),
+		Source:            base,
+		Destination:       base,
+		DestinationStatic: base,
+		Os:                &afero.OsFs{},
+		WorkingDir:        getWorkingDirFs(base, cfg),
 	}
 }
 
