@@ -33,9 +33,10 @@ func newPagesProcessor(h *HugoSites, sp *source.SourceSpec) *pagesProcessor {
 	procs := make(map[string]pagesCollectorProcessorProvider)
 	for _, s := range h.Sites {
 		procs[s.Lang()] = &sitePagesProcessor{
-			m:           s.pageMap,
-			errorSender: s.h,
-			itemChan:    make(chan interface{}, config.GetNumWorkerMultiplier()*2),
+			m:                  s.pageMap,
+			errorSender:        s.h,
+			itemChan:           make(chan interface{}, config.GetNumWorkerMultiplier()*2),
+			renderStaticToDisk: h.Cfg.GetBool("renderStaticToDisk"),
 		}
 	}
 	return &pagesProcessor{
@@ -118,6 +119,8 @@ type sitePagesProcessor struct {
 	ctx       context.Context
 	itemChan  chan interface{}
 	itemGroup *errgroup.Group
+
+	renderStaticToDisk bool
 }
 
 func (p *sitePagesProcessor) Process(item interface{}) error {
@@ -162,7 +165,12 @@ func (p *sitePagesProcessor) copyFile(fim hugofs.FileMetaInfo) error {
 
 	defer f.Close()
 
-	return s.publish(&s.PathSpec.ProcessingStats.Files, target, f)
+	fs := s.PublishFs
+	if p.renderStaticToDisk {
+		fs = s.PublishFsStatic
+	}
+
+	return s.publish(&s.PathSpec.ProcessingStats.Files, target, f, fs)
 }
 
 func (p *sitePagesProcessor) doProcess(item interface{}) error {
